@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 #
-# Copyright (C) 2013-2022 Charles E. Vejnar
+# Copyright © 2013 Charles E. Vejnar
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -12,6 +12,8 @@ import json
 import os
 import re
 
+all_exts = ['.bam', '.bedgraph', '.bin', '.bw', '.csv', '.fastq', '.json', '.log', '.pdf', '.sam', '.tab', '.txt']
+
 def parse_fastq_filename(fname, regex=r'.+_([R,I][1,2,3])\.f'):
     m = re.match(regex, fname)
     if m:
@@ -39,3 +41,14 @@ def get_fastqs_per_end(path_seq, paired=False, fastq_exts=None, read_regexs=None
 
 def write_report(fname, report):
     json.dump(report, open(fname+'.json', 'w'), sort_keys=True, indent=4, separators=(',', ': '))
+
+def label2var(label):
+    if label is None:
+        return None
+    else:
+        return label.replace(' ', '_').replace('-', '_').replace('%', 'p').replace('/', '_')
+
+def get_first_key(l, d):
+    for k in l:
+        if k in d:
+            return d[k]
