@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 #
-# Copyright (C) 2013-2022 Charles E. Vejnar
+# Copyright © 2013 Charles E. Vejnar
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -13,6 +13,7 @@ import argparse
 import sys
 
 import labxpipe_scripts.lxpipe_demultiplex
+import labxpipe_scripts.lxpipe_extract
 import labxpipe_scripts.lxpipe_generate
 import labxpipe_scripts.lxpipe_merge_count
 import labxpipe_scripts.lxpipe_profile
@@ -23,6 +24,7 @@ import labxpipe_scripts.lxpipe_trackhub
 subcommands = {
     'run': labxpipe_scripts.lxpipe_run,
     'report': labxpipe_scripts.lxpipe_report,
+    'extract': labxpipe_scripts.lxpipe_extract,
     'merge-count': labxpipe_scripts.lxpipe_merge_count,
     'generate': labxpipe_scripts.lxpipe_generate,
     'profile': labxpipe_scripts.lxpipe_profile,
